@@ -4,8 +4,7 @@
 """
 
 
-# pylint: disable=E0012,R0205
-class Sampler(object):
+class Sampler:
     """Abstract tracing span sampler."""
 
     def sample(self, operation_name, trace_id, duration):
